# Generated by Django 3.0.3 on 2020-03-24 18:30

from django.conf import settings
import django.contrib.postgres.fields
import django.contrib.postgres.fields.jsonb
import django.contrib.postgres.indexes
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Algorithm',
            fields=[
                ('value', models.CharField(max_length=128, primary_key=True, serialize=False, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Cluster',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('location', models.CharField(help_text='Human-readable location of the cluster.', max_length=128)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CopyReason',
            fields=[
                ('value', models.CharField(max_length=128, primary_key=True, serialize=False, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Cycle',
            fields=[
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128, primary_key=True, serialize=False)),
                ('start', models.DateTimeField(help_text='Moment at which the cycle starts, that is, when its projects can run.')),
                ('stop', models.DateTimeField(help_text='Moment at which the cycle officially ends.')),
                ('number', models.IntegerField(help_text='Cycle number.')),
                ('standard_hours', models.IntegerField(help_text='Number of offered hours for standard observations.')),
                ('expert_hours', models.IntegerField(help_text='Number of offered hours for expert observations.')),
                ('filler_hours', models.IntegerField(help_text='Number of offered hours for filler observations.')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Dataformat',
            fields=[
                ('value', models.CharField(max_length=128, primary_key=True, serialize=False, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Dataproduct',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('filename', models.CharField(help_text='Name of the file (or top-level directory) of the dataproduct. Adheres to a naming convention, but is not meant for parsing.', max_length=128)),
                ('directory', models.CharField(help_text='Directory where this dataproduct is (to be) stored.', max_length=1024)),
                ('deleted_since', models.DateTimeField(help_text='When this dataproduct was removed from disk, or NULL if not deleted (NULLable).', null=True)),
                ('pinned_since', models.DateTimeField(help_text='When this dataproduct was pinned to disk, that is, forbidden to be removed, or NULL if not pinned (NULLable).', null=True)),
                ('specifications_doc', django.contrib.postgres.fields.jsonb.JSONField(help_text='Dataproduct properties (f.e. beam, subband), to distinguish them when produced by the same task, and to act as input for selections in the Task Input and Work Request Relation Blueprint objects.')),
                ('do_cancel', models.DateTimeField(help_text='When this dataproduct was cancelled (NULLable).  Cancelling a dataproduct triggers cleanup if necessary.', null=True)),
                ('expected_size', models.BigIntegerField(help_text='Expected size of dataproduct size, in bytes. Used for scheduling purposes. NULL if size is unknown (NULLable).', null=True)),
                ('size', models.BigIntegerField(help_text='Dataproduct size, in bytes. Used for accounting purposes. NULL if size is (yet) unknown (NULLable).', null=True)),
                ('feedback_doc', django.contrib.postgres.fields.jsonb.JSONField(help_text='Dataproduct properties, as reported by the producing process.')),
                ('dataformat', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='tmssapp.Dataformat')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DataproductFeedbackTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('version', models.CharField(help_text='Version of this template (with respect to other templates of the same name).', max_length=128)),
                ('schema', django.contrib.postgres.fields.jsonb.JSONField(help_text='Schema for the configurable parameters needed to use this template.')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DataproductSpecificationsTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('version', models.CharField(help_text='Version of this template (with respect to other templates of the same name).', max_length=128)),
                ('schema', django.contrib.postgres.fields.jsonb.JSONField(help_text='Schema for the configurable parameters needed to use this template.')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Datatype',
            fields=[
                ('value', models.CharField(max_length=128, primary_key=True, serialize=False, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='GeneratorTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('version', models.CharField(help_text='Version of this template (with respect to other templates of the same name).', max_length=128)),
                ('schema', django.contrib.postgres.fields.jsonb.JSONField(help_text='Schema for the configurable parameters needed to use this template.')),
                ('create_function', models.CharField(help_text='Python function to call to execute the generator.', max_length=128)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Project',
            fields=[
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128, primary_key=True, serialize=False)),
                ('priority', models.IntegerField(default=0, help_text='Priority of this project w.r.t. other projects. Projects can interrupt observations of lower-priority projects.')),
                ('can_trigger', models.BooleanField(default=False, help_text='True if this project is allowed to supply observation requests on the fly, possibly interrupting currently running observations (responsive telescope).')),
                ('private_data', models.BooleanField(default=True, help_text='True if data of this project is sensitive. Sensitive data is not made public.')),
                ('expert', models.BooleanField(default=False, help_text='Expert projects put more responsibility on the PI.')),
                ('filler', models.BooleanField(default=False, help_text='Use this project to fill up idle telescope time.')),
                ('cycle', models.ForeignKey(help_text='Cycle(s) to which this project belongs (NULLable).', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='projects', to='tmssapp.Cycle')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Role',
            fields=[
                ('value', models.CharField(max_length=128, primary_key=True, serialize=False, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ScheduleMethod',
            fields=[
                ('value', models.CharField(max_length=128, primary_key=True, serialize=False, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SchedulingSet',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('generator_doc', django.contrib.postgres.fields.jsonb.JSONField(help_text='Parameters for the generator (NULLable).', null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SchedulingUnitBlueprint',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('requirements_doc', django.contrib.postgres.fields.jsonb.JSONField(help_text='Scheduling and/or quality requirements for this scheduling unit (IMMUTABLE).')),
                ('do_cancel', models.BooleanField()),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SchedulingUnitDraft',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('requirements_doc', django.contrib.postgres.fields.jsonb.JSONField(help_text='Scheduling and/or quality requirements for this run.')),
                ('generator_instance_doc', django.contrib.postgres.fields.jsonb.JSONField(help_text='Parameter value that generated this run draft (NULLable).', null=True)),
                ('copies', models.ForeignKey(help_text='Source reference, if we are a copy (NULLable).', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='copied_from', to='tmssapp.SchedulingUnitDraft')),
                ('copy_reason', models.ForeignKey(help_text='Reason why source was copied (NULLable).', null=True, on_delete=django.db.models.deletion.PROTECT, to='tmssapp.CopyReason')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SchedulingUnitTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('version', models.CharField(help_text='Version of this template (with respect to other templates of the same name).', max_length=128)),
                ('schema', django.contrib.postgres.fields.jsonb.JSONField(help_text='Schema for the configurable parameters needed to use this template.')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='StationType',
            fields=[
                ('value', models.CharField(max_length=128, primary_key=True, serialize=False, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Subtask',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('start_time', models.DateTimeField(help_text='Start this subtask at the specified time (NULLable).', null=True)),
                ('stop_time', models.DateTimeField(help_text='Stop this subtask at the specified time (NULLable).', null=True)),
                ('specifications_doc', django.contrib.postgres.fields.jsonb.JSONField(help_text='Final specifications, as input for the controller.')),
                ('do_cancel', models.DateTimeField(help_text='Timestamp when the subtask has been ordered to cancel (NULLable).', null=True)),
                ('priority', models.IntegerField(help_text='Absolute priority of this subtask (higher value means more important).')),
                ('scheduler_input_doc', django.contrib.postgres.fields.jsonb.JSONField(help_text='Partial specifications, as input for the scheduler.')),
                ('cluster', models.ForeignKey(help_text='Where the Subtask is scheduled to run (NULLable).', null=True, on_delete=django.db.models.deletion.PROTECT, to='tmssapp.Cluster')),
                ('created_or_updated_by_user', models.ForeignKey(editable=False, help_text='The user who created / updated the subtask.', null=True, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL)),
                ('schedule_method', models.ForeignKey(help_text='Which method to use for scheduling this Subtask. One of (MANUAL, BATCH, DYNAMIC).', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.ScheduleMethod')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SubtaskConnector',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('dataformats', models.ManyToManyField(blank=True, to='tmssapp.Dataformat')),
                ('datatype', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='tmssapp.Datatype')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SubtaskInputSelectionTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('version', models.CharField(help_text='Version of this template (with respect to other templates of the same name).', max_length=128)),
                ('schema', django.contrib.postgres.fields.jsonb.JSONField(help_text='Schema for the configurable parameters needed to use this template.')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SubtaskState',
            fields=[
                ('value', models.CharField(max_length=128, primary_key=True, serialize=False, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SubtaskType',
            fields=[
                ('value', models.CharField(max_length=128, primary_key=True, serialize=False, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Tags',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=128)),
                ('description', models.CharField(max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name='TaskBlueprint',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('specifications_doc', django.contrib.postgres.fields.jsonb.JSONField(help_text='Schedulings for this task (IMMUTABLE).')),
                ('do_cancel', models.BooleanField(help_text='Cancel this task.')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TaskConnectors',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('dataformats', models.ManyToManyField(blank=True, to='tmssapp.Dataformat')),
                ('datatype', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='tmssapp.Datatype')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TaskDraft',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('specifications_doc', django.contrib.postgres.fields.jsonb.JSONField(help_text='Specifications for this task.')),
                ('copies', models.ForeignKey(help_text='Source reference, if we are a copy (NULLable).', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='copied_from', to='tmssapp.TaskDraft')),
                ('copy_reason', models.ForeignKey(help_text='Reason why source was copied (NULLable).', null=True, on_delete=django.db.models.deletion.PROTECT, to='tmssapp.CopyReason')),
                ('scheduling_unit_draft', models.ForeignKey(help_text='Scheduling Unit draft to which this task draft belongs.', on_delete=django.db.models.deletion.CASCADE, related_name='task_drafts', to='tmssapp.SchedulingUnitDraft')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TaskTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('version', models.CharField(help_text='Version of this template (with respect to other templates of the same name).', max_length=128)),
                ('schema', django.contrib.postgres.fields.jsonb.JSONField(help_text='Schema for the configurable parameters needed to use this template.')),
                ('validation_code_js', models.CharField(help_text='JavaScript code for additional (complex) validation.', max_length=128)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='WorkRelationSelectionTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('version', models.CharField(help_text='Version of this template (with respect to other templates of the same name).', max_length=128)),
                ('schema', django.contrib.postgres.fields.jsonb.JSONField(help_text='Schema for the configurable parameters needed to use this template.')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TaskRelationDraft',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('selection_doc', django.contrib.postgres.fields.jsonb.JSONField(help_text='Filter for selecting dataproducts from the output role.')),
                ('consumer', models.ForeignKey(help_text='Task Draft that has the input connector.', on_delete=django.db.models.deletion.CASCADE, related_name='consumed_by', to='tmssapp.TaskDraft')),
                ('dataformat', models.ForeignKey(help_text='Selected data format to use. One of (MS, HDF5).', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.Dataformat')),
                ('input', models.ForeignKey(help_text='Input connector of consumer.', on_delete=django.db.models.deletion.CASCADE, related_name='inputs_task_relation_draft', to='tmssapp.TaskConnectors')),
                ('output', models.ForeignKey(help_text='Output connector of producer.', on_delete=django.db.models.deletion.CASCADE, related_name='outputs_task_relation_draft', to='tmssapp.TaskConnectors')),
                ('producer', models.ForeignKey(help_text='Task Draft that has the output connector. NOTE: The producer does typically, but not necessarily, belong to the same Scheduling Unit (or even the same Project) as the consumer.', on_delete=django.db.models.deletion.CASCADE, related_name='produced_by', to='tmssapp.TaskDraft')),
                ('selection_template', models.ForeignKey(help_text='Schema used for selection_doc.', on_delete=django.db.models.deletion.CASCADE, to='tmssapp.WorkRelationSelectionTemplate')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TaskRelationBlueprint',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('selection_doc', django.contrib.postgres.fields.jsonb.JSONField(help_text='Filter for selecting dataproducts from the output role.')),
                ('consumer', models.ForeignKey(help_text='Task Blueprint that has the input connector.', on_delete=django.db.models.deletion.CASCADE, related_name='consumed_by', to='tmssapp.TaskBlueprint')),
                ('dataformat', models.ForeignKey(help_text='Selected data format to use.', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.Dataformat')),
                ('draft', models.ForeignKey(help_text='Task Relation Draft which this work request instantiates.', on_delete=django.db.models.deletion.CASCADE, related_name='related_task_relation_blueprint', to='tmssapp.TaskRelationDraft')),
                ('input', models.ForeignKey(help_text='Input connector of consumer.', on_delete=django.db.models.deletion.CASCADE, related_name='inputs_task_relation_blueprint', to='tmssapp.TaskConnectors')),
                ('output', models.ForeignKey(help_text='Output connector of producer.', on_delete=django.db.models.deletion.CASCADE, related_name='outputs_task_relation_blueprint', to='tmssapp.TaskConnectors')),
                ('producer', models.ForeignKey(help_text='Task Blueprint that has the output connector.', on_delete=django.db.models.deletion.CASCADE, related_name='produced_by', to='tmssapp.TaskBlueprint')),
                ('selection_template', models.ForeignKey(help_text='Schema used for selection_doc.', on_delete=django.db.models.deletion.CASCADE, to='tmssapp.WorkRelationSelectionTemplate')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='taskdraft',
            name='specifications_template',
            field=models.ForeignKey(help_text='Schema used for requirements_doc.', on_delete=django.db.models.deletion.CASCADE, to='tmssapp.TaskTemplate'),
        ),
        migrations.AddField(
            model_name='taskconnectors',
            name='input_of',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='inputs', to='tmssapp.TaskTemplate'),
        ),
        migrations.AddField(
            model_name='taskconnectors',
            name='output_of',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='outputs', to='tmssapp.TaskTemplate'),
        ),
        migrations.AddField(
            model_name='taskconnectors',
            name='role',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='tmssapp.Role'),
        ),
        migrations.AddField(
            model_name='taskblueprint',
            name='draft',
            field=models.ForeignKey(help_text='Task Draft which this task instantiates.', on_delete=django.db.models.deletion.CASCADE, related_name='related_task_blueprint', to='tmssapp.TaskDraft'),
        ),
        migrations.AddField(
            model_name='taskblueprint',
            name='scheduling_unit_blueprint',
            field=models.ForeignKey(help_text='Scheduling Unit Blueprint to which this task belongs.', on_delete=django.db.models.deletion.CASCADE, to='tmssapp.SchedulingUnitBlueprint'),
        ),
        migrations.AddField(
            model_name='taskblueprint',
            name='specifications_template',
            field=models.ForeignKey(help_text='Schema used for specifications_doc (IMMUTABLE).', on_delete=django.db.models.deletion.CASCADE, to='tmssapp.TaskTemplate'),
        ),
        migrations.CreateModel(
            name='SubtaskTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('version', models.CharField(help_text='Version of this template (with respect to other templates of the same name).', max_length=128)),
                ('schema', django.contrib.postgres.fields.jsonb.JSONField(help_text='Schema for the configurable parameters needed to use this template.')),
                ('queue', models.BooleanField(default=False)),
                ('realtime', models.BooleanField(default=False)),
                ('type', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='tmssapp.SubtaskType')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SubtaskStateLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('user_identifier', models.CharField(editable=False, help_text='The ID of the user who changed the state of the subtask.', null=True, max_length=128)),
                ('new_state', models.ForeignKey(editable=False, help_text='Subtask state after update (see Subtask State Machine).', on_delete=django.db.models.deletion.PROTECT, related_name='is_new_state_of', to='tmssapp.SubtaskState')),
                ('old_state', models.ForeignKey(editable=False, help_text='Subtask state before update (see Subtask State Machine).', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='is_old_state_of', to='tmssapp.SubtaskState')),
                ('subtask', models.ForeignKey(editable=False, help_text='Subtask to which this state change refers.', on_delete=django.db.models.deletion.CASCADE, to='tmssapp.Subtask')),
                ('user', models.ForeignKey(editable=False, help_text='The user who changed the state of the subtask.', null=True, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SubtaskOutput',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('connector', models.ForeignKey(help_text='Which connector this Subtask Output implements.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='tmssapp.SubtaskConnector')),
                ('subtask', models.ForeignKey(help_text='Subtask to which this output specification refers.', on_delete=django.db.models.deletion.CASCADE, to='tmssapp.Subtask')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SubtaskInput',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('selection_doc', django.contrib.postgres.fields.jsonb.JSONField(help_text='Filter to apply to the dataproducts of the producer, to derive input dataproducts when scheduling.')),
                ('connector', models.ForeignKey(help_text='Which connector this Task Input implements.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='tmssapp.SubtaskConnector')),
                ('dataproducts', models.ManyToManyField(help_text='The Dataproducts resulting from application of the filter at time of scheduling Although the dataproducts are simply the result of applying the filter on immutable data, the filter application could change over time. We thus store the result of this filtering directly to retain which input was specified for the task..', to='tmssapp.Dataproduct')),
                ('producer', models.ForeignKey(help_text='The Subtask Output providing the input dataproducts.', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.SubtaskOutput')),
                ('selection_template', models.ForeignKey(help_text='Schema used for selection_doc.', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.SubtaskInputSelectionTemplate')),
                ('subtask', models.ForeignKey(help_text='Subtask to which this input specification refers.', on_delete=django.db.models.deletion.CASCADE, to='tmssapp.Subtask')),
                ('task_relation_blueprint', models.ForeignKey(help_text='Task Relation Blueprint which this Subtask Input implements (NULLable).', null=True, on_delete=django.db.models.deletion.SET_NULL, to='tmssapp.TaskRelationBlueprint')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='subtaskconnector',
            name='input_of',
            field=models.ForeignKey(blank=True, on_delete=django.db.models.deletion.PROTECT, related_name='outputs', to='tmssapp.SubtaskTemplate'),
        ),
        migrations.AddField(
            model_name='subtaskconnector',
            name='output_of',
            field=models.ForeignKey(blank=True, on_delete=django.db.models.deletion.PROTECT, related_name='inputs', to='tmssapp.SubtaskTemplate'),
        ),
        migrations.AddField(
            model_name='subtaskconnector',
            name='role',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='tmssapp.Role'),
        ),
        migrations.AddField(
            model_name='subtask',
            name='specifications_template',
            field=models.ForeignKey(help_text='Schema used for specifications_doc.', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.SubtaskTemplate'),
        ),
        migrations.AddField(
            model_name='subtask',
            name='state',
            field=models.ForeignKey(help_text='Subtask state (see Subtask State Machine).', on_delete=django.db.models.deletion.PROTECT, related_name='task_states', to='tmssapp.SubtaskState'),
        ),
        migrations.AddField(
            model_name='subtask',
            name='task_blueprint',
            field=models.ForeignKey(help_text='Task Blueprint to which this Subtask belongs.', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='subtasks', to='tmssapp.TaskBlueprint'),
        ),
        migrations.AddField(
            model_name='schedulingunitdraft',
            name='requirements_template',
            field=models.ForeignKey(help_text='Schema used for requirements_doc.', on_delete=django.db.models.deletion.CASCADE, to='tmssapp.SchedulingUnitTemplate'),
        ),
        migrations.AddField(
            model_name='schedulingunitdraft',
            name='scheduling_set',
            field=models.ForeignKey(help_text='Set to which this scheduling unit draft belongs.', on_delete=django.db.models.deletion.CASCADE, related_name='scheduling_unit_drafts', to='tmssapp.SchedulingSet'),
        ),
        migrations.AddField(
            model_name='schedulingunitblueprint',
            name='draft',
            field=models.ForeignKey(help_text='Scheduling Unit Draft which this run instantiates.', on_delete=django.db.models.deletion.CASCADE, related_name='related_scheduling_unit_blueprint', to='tmssapp.SchedulingUnitDraft'),
        ),
        migrations.AddField(
            model_name='schedulingunitblueprint',
            name='requirements_template',
            field=models.ForeignKey(help_text='Schema used for requirements_doc (IMMUTABLE).', on_delete=django.db.models.deletion.CASCADE, to='tmssapp.SchedulingUnitTemplate'),
        ),
        migrations.AddField(
            model_name='schedulingset',
            name='generator_source',
            field=models.ForeignKey(help_text='Reference for the generator to an existing collection of specifications (NULLable).', null=True, on_delete=django.db.models.deletion.SET_NULL, to='tmssapp.SchedulingUnitDraft'),
        ),
        migrations.AddField(
            model_name='schedulingset',
            name='generator_template',
            field=models.ForeignKey(help_text='Generator for the scheduling units in this set (NULLable).', null=True, on_delete=django.db.models.deletion.SET_NULL, to='tmssapp.GeneratorTemplate'),
        ),
        migrations.AddField(
            model_name='schedulingset',
            name='project',
            field=models.ForeignKey(help_text='Project to which this scheduling set belongs.', on_delete=django.db.models.deletion.PROTECT, related_name='scheduling_sets', to='tmssapp.Project'),
        ),
        migrations.CreateModel(
            name='Filesystem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('capacity', models.BigIntegerField(help_text='Capacity in bytes')),
                ('cluster', models.ForeignKey(help_text='Cluster hosting this filesystem.', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.Cluster')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DefaultWorkRelationSelectionTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(max_length=128, unique=True)),
                ('template', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='tmssapp.WorkRelationSelectionTemplate')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DefaultTaskTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(max_length=128, unique=True)),
                ('template', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='tmssapp.TaskTemplate')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DefaultSubtaskTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(max_length=128, unique=True)),
                ('template', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='tmssapp.SubtaskTemplate')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DefaultSchedulingUnitTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(max_length=128, unique=True)),
                ('template', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='tmssapp.SchedulingUnitTemplate')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DefaultGeneratorTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(max_length=128, unique=True)),
                ('template', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='tmssapp.GeneratorTemplate')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DefaultDataproductSpecificationsTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(max_length=128, unique=True)),
                ('template', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='tmssapp.DataproductSpecificationsTemplate')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DataproductTransform',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('identity', models.BooleanField(help_text='TRUE if this transform only copies, tars, or losslessly compresses its input, FALSE if the transform changes the data. Allows for efficient reasoning about data duplication.')),
                ('input', models.ForeignKey(help_text='A dataproduct that was the input of a transformation.', on_delete=django.db.models.deletion.PROTECT, related_name='inputs', to='tmssapp.Dataproduct')),
                ('output', models.ForeignKey(help_text='A dataproduct that was produced from the input dataproduct.', on_delete=django.db.models.deletion.PROTECT, related_name='outputs', to='tmssapp.Dataproduct')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DataproductHash',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('hash', models.CharField(help_text='Hash value.', max_length=128)),
                ('algorithm', models.ForeignKey(help_text='Algorithm used (MD5, AES256).', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.Algorithm')),
                ('dataproduct', models.ForeignKey(help_text='The dataproduct to which this hash refers.', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.Dataproduct')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DataproductArchiveInfo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('storage_ticket', models.CharField(help_text='Archive-system identifier.', max_length=128)),
                ('public_since', models.DateTimeField(help_text='Dataproduct is available for public download since this moment, or NULL if dataproduct is not (NULLable).', null=True)),
                ('corrupted_since', models.DateTimeField(help_text='Earliest timestamp from which this dataproduct is known to be partially or fully corrupt, or NULL if dataproduct is not known to be corrupt (NULLable).', null=True)),
                ('dataproduct', models.ForeignKey(help_text='A dataproduct residing in the archive.', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.Dataproduct')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='dataproduct',
            name='feedback_template',
            field=models.ForeignKey(help_text='Schema used for feedback_doc.', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.DataproductFeedbackTemplate'),
        ),
        migrations.AddField(
            model_name='dataproduct',
            name='producer',
            field=models.ForeignKey(help_text='Subtask Output which generates this dataproduct.', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.SubtaskOutput'),
        ),
        migrations.AddField(
            model_name='dataproduct',
            name='specifications_template',
            field=models.ForeignKey(help_text='Schema used for specifications_doc.', on_delete=django.db.models.deletion.CASCADE, to='tmssapp.DataproductSpecificationsTemplate'),
        ),
        migrations.CreateModel(
            name='AntennaSet',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(help_text='A longer description of this object.', max_length=255)),
                ('rcus', django.contrib.postgres.fields.ArrayField(base_field=models.IntegerField(), size=128)),
                ('inputs', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, size=128)),
                ('station_type', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='tmssapp.StationType')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddIndex(
            model_name='taskrelationdraft',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_tas_tags_aeef84_gin'),
        ),
        migrations.AddIndex(
            model_name='taskrelationblueprint',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_tas_tags_256437_gin'),
        ),
        migrations.AddIndex(
            model_name='taskconnectors',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_tas_tags_0ebd6d_gin'),
        ),
        migrations.AddIndex(
            model_name='subtaskstatelog',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_sub_tags_70e4a2_gin'),
        ),
        migrations.AddIndex(
            model_name='subtaskoutput',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_sub_tags_e25b4c_gin'),
        ),
        migrations.AddIndex(
            model_name='subtaskinput',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_sub_tags_fb9960_gin'),
        ),
        migrations.AddIndex(
            model_name='subtaskconnector',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_sub_tags_60e299_gin'),
        ),
        migrations.AddIndex(
            model_name='subtask',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_sub_tags_d2fc43_gin'),
        ),
        migrations.AddIndex(
            model_name='defaultworkrelationselectiontemplate',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_def_tags_b652d9_gin'),
        ),
        migrations.AddIndex(
            model_name='defaulttasktemplate',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_def_tags_c88200_gin'),
        ),
        migrations.AddIndex(
            model_name='defaultsubtasktemplate',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_def_tags_e9c73d_gin'),
        ),
        migrations.AddIndex(
            model_name='defaultschedulingunittemplate',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_def_tags_3ab2d6_gin'),
        ),
        migrations.AddIndex(
            model_name='defaultgeneratortemplate',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_def_tags_89c89d_gin'),
        ),
        migrations.AddIndex(
            model_name='defaultdataproductspecificationstemplate',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_def_tags_269b1f_gin'),
        ),
        migrations.AddIndex(
            model_name='dataproducttransform',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_dat_tags_380c1f_gin'),
        ),
        migrations.AddIndex(
            model_name='dataproducthash',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_dat_tags_dae145_gin'),
        ),
        migrations.AddIndex(
            model_name='dataproductarchiveinfo',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_dat_tags_ebf2ef_gin'),
        ),
        migrations.AddIndex(
            model_name='dataproduct',
            index=django.contrib.postgres.indexes.GinIndex(fields=['tags'], name='tmssapp_dat_tags_5932a3_gin'),
        ),
    ]
